@@ -813,6 +813,12 @@ e_book_backend_exchange_connect (EBookBackendExchange *be, GError **perror)
 	e_folder_exchange_subscribe (bepriv->folder,
 				     E2K_CONTEXT_OBJECT_CHANGED, 30,
 				     subscription_notify, be);
+	e_folder_exchange_subscribe (bepriv->folder,
+				     E2K_CONTEXT_OBJECT_ADDED, 30,
+				     subscription_notify, be);
+	e_folder_exchange_subscribe (bepriv->folder,
+				     E2K_CONTEXT_OBJECT_REMOVED, 30,
+				     subscription_notify, be);
 
 	bepriv->connected = TRUE;
 	e_book_backend_set_is_loaded (E_BOOK_BACKEND (be), TRUE);
@@ -1119,19 +1125,19 @@ proppatch_address (PropMapping *prop_mapping,
 		return;
 	}
 
-	new_addrprops [ADDRPROP_POSTOFFICEBOX]		= new_address->po;
-	new_addrprops [ADDRPROP_STREET]			= new_address->street;
-	new_addrprops [ADDRPROP_CITY]			= new_address->locality;
-	new_addrprops [ADDRPROP_STATE]			= new_address->region;
-	new_addrprops [ADDRPROP_POSTALCODE]		= new_address->code;
-	new_addrprops [ADDRPROP_COUNTRY]		= new_address->country;
+	new_addrprops[ADDRPROP_POSTOFFICEBOX]		= new_address->po;
+	new_addrprops[ADDRPROP_STREET]			= new_address->street;
+	new_addrprops[ADDRPROP_CITY]			= new_address->locality;
+	new_addrprops[ADDRPROP_STATE]			= new_address->region;
+	new_addrprops[ADDRPROP_POSTALCODE]		= new_address->code;
+	new_addrprops[ADDRPROP_COUNTRY]		= new_address->country;
 	if (cur_address) {
-		cur_addrprops [ADDRPROP_POSTOFFICEBOX]	= cur_address->po;
-		cur_addrprops [ADDRPROP_STREET]		= cur_address->street;
-		cur_addrprops [ADDRPROP_CITY]		= cur_address->locality;
-		cur_addrprops [ADDRPROP_STATE]		= cur_address->region;
-		cur_addrprops [ADDRPROP_POSTALCODE]	= cur_address->code;
-		cur_addrprops [ADDRPROP_COUNTRY]	= cur_address->country;
+		cur_addrprops[ADDRPROP_POSTOFFICEBOX]	= cur_address->po;
+		cur_addrprops[ADDRPROP_STREET]		= cur_address->street;
+		cur_addrprops[ADDRPROP_CITY]		= cur_address->locality;
+		cur_addrprops[ADDRPROP_STATE]		= cur_address->region;
+		cur_addrprops[ADDRPROP_POSTALCODE]	= cur_address->code;
+		cur_addrprops[ADDRPROP_COUNTRY]	= cur_address->country;
 	}
 
 	for (i = 0; i < ADDRPROP_LAST; i++) {
@@ -2960,7 +2966,7 @@ e_book_backend_exchange_dispose (GObject *object)
 			g_free (be->priv->original_uri);
 
 		if (be->priv->account)
-			g_object_unref (be->priv->account);
+			be->priv->account = NULL;
 
 		if (be->priv->ops)
 			g_hash_table_destroy (be->priv->ops);
